@@ -7,8 +7,8 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/Portability.hh"
-#include "log4cpp/AppenderSkeleton.hh"
+#include <log4cpp/Portability.hh>
+#include <log4cpp/AppenderSkeleton.hh>
 
 namespace log4cpp {
 
