@@ -7,16 +7,16 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/Portability.hh"
+#include <log4cpp/Portability.hh>
 
 #ifdef LOG4CPP_HAVE_UNISTD_H
 #    include <unistd.h>
 #endif
 
-#include "log4cpp/OstringStream.hh"
-#include "log4cpp/Category.hh"
-#include "log4cpp/HierarchyMaintainer.hh"
-#include "log4cpp/NDC.hh"
+#include <log4cpp/OstringStream.hh>
+#include <log4cpp/Category.hh>
+#include <log4cpp/HierarchyMaintainer.hh>
+#include <log4cpp/NDC.hh>
 
 namespace log4cpp {
 
@@ -40,7 +40,7 @@ namespace log4cpp {
         return HierarchyMaintainer::getDefaultMaintainer().getExistingInstance(name);
     }
 
-    std::set<Category*>* Category::getCurrentCategories() {
+    std::vector<Category*>* Category::getCurrentCategories() {
         return HierarchyMaintainer::getDefaultMaintainer().
             getCurrentCategories();
     }
@@ -68,14 +68,15 @@ namespace log4cpp {
         return _priority; 
     }
 
-    void Category::setPriority(Priority::Value priority) {
-        if ((priority != Priority::NOTSET) || (getParent() != NULL)) {
+    void Category::setPriority(Priority::Value priority)
+    throw(std::invalid_argument) {
+        if ((priority < Priority::NOTSET) || (getParent() != NULL)) {
             _priority = priority;
         } else {
             /* caller tried to set NOTSET priority to root Category. 
                Bad caller!
-               Will ignore for now.
             */
+            throw std::invalid_argument("cannot set priority NOTSET on Root Category");
         }
     }
     
@@ -83,90 +84,122 @@ namespace log4cpp {
         // REQUIRE(rootCategory->getPriority() != Priority::NOTSET)
         
         const Category* c = this;
-        while(c->getPriority() == Priority::NOTSET) { 
+        while(c->getPriority() >= Priority::NOTSET) { 
             c = c->getParent();
         }
         
         return c->getPriority();
     }
     
-    void Category::addAppender(Appender* appender) {
+    void Category::addAppender(Appender* appender) 
+    throw(std::invalid_argument) {
         if (appender) {
-            AppenderSet::iterator i = _appender.find(appender);
-            if (_appender.end() == i) {
-                // not found
-                _appender.insert(appender);
-                _ownsAppender[appender] = true;
+            threading::ScopedLock lock(_appenderSetMutex);
+            {
+                AppenderSet::iterator i = _appender.find(appender);
+                if (_appender.end() == i) {
+                    // not found
+                    _appender.insert(appender);
+                    _ownsAppender[appender] = true;
+                }
             }
+        } else {
+            throw std::invalid_argument("NULL appender");
         }
     }
     
     void Category::addAppender(Appender& appender) {
-        AppenderSet::iterator i = _appender.find(&appender);
-        if (_appender.end() == i) {
-            _appender.insert(&appender);
-            _ownsAppender[&appender] = false;
+        threading::ScopedLock lock(_appenderSetMutex);
+        {
+            AppenderSet::iterator i = _appender.find(&appender);
+            if (_appender.end() == i) {
+                _appender.insert(&appender);
+                _ownsAppender[&appender] = false;
+            }
         }
     }
     
     Appender* Category::getAppender() const {
-        AppenderSet::const_iterator i = _appender.begin();
-        return (_appender.end() == i) ? NULL : *i;
+        threading::ScopedLock lock(_appenderSetMutex);
+        {
+            AppenderSet::const_iterator i = _appender.begin();
+            return (_appender.end() == i) ? NULL : *i;
+        }
     }
 
     Appender* Category::getAppender(const std::string& name) const {
-        AppenderSet::const_iterator i = _appender.begin();
-        if (_appender.end() != i) {
-            // found
-            return((*i)->getAppender(name));
+        threading::ScopedLock lock(_appenderSetMutex);
+        {
+            AppenderSet::const_iterator i = _appender.begin();
+            if (_appender.end() != i) {
+                // found
+                return((*i)->getAppender(name));
+            }
+            else {
+                return(NULL);
+            }
+        }
+    }
+
+    AppenderSet Category::getAllAppenders() const {
+        threading::ScopedLock lock(_appenderSetMutex);
+        {
+            return _appender;
         }
-		else {
-			return(NULL);
-		}
     }
 
     void Category::removeAllAppenders() {
-        AppenderSet::iterator i2, i = _appender.begin();
-        while (i != _appender.end()) {
-            // found
-            OwnsAppenderMap::iterator i3;
-            if (ownsAppender(*i, i3)) {
-                _ownsAppender.erase(i3);
-                delete (*i);
+        threading::ScopedLock lock(_appenderSetMutex);
+        {
+            for (AppenderSet::iterator i = _appender.begin();
+                 i != _appender.end(); i++) {
+                // found
+                OwnsAppenderMap::iterator i2;
+                if (ownsAppender(*i, i2)) {
+                    delete (*i);
+                }
             }
 
-            i2 = i++;
-            _appender.erase(i2);
+            _ownsAppender.clear();
+            _appender.clear();           
         }
     }
 
     void Category::removeAppender(Appender* appender) {
-        AppenderSet::iterator i = _appender.find(appender);
-        if (_appender.end() != i) {            
-            OwnsAppenderMap::iterator i2;
-            if (ownsAppender(*i, i2)) {
-                _ownsAppender.erase(i2);
-                delete (*i);
+        threading::ScopedLock lock(_appenderSetMutex);
+        {
+            AppenderSet::iterator i = _appender.find(appender);
+            if (_appender.end() != i) {            
+                OwnsAppenderMap::iterator i2;
+                if (ownsAppender(*i, i2)) {
+                    _ownsAppender.erase(i2);
+                    delete (*i);
+                }
+                _appender.erase(i);
+            } else {
+                // appender not found 
             }
-            _appender.erase(i);
-        } else {
-            // appender not found 
         }
     }
 
     bool Category::ownsAppender(Appender* appender) const throw() {
         bool owned = false;
 
-        if (NULL != appender) {            
-            OwnsAppenderMap::const_iterator i = _ownsAppender.find(appender);
-            if (_ownsAppender.end() != i) {
-                owned = (*i).second;
+        threading::ScopedLock lock(_appenderSetMutex);
+        {
+            if (NULL != appender) {            
+                OwnsAppenderMap::const_iterator i =
+                    _ownsAppender.find(appender);
+                if (_ownsAppender.end() != i) {
+                    owned = (*i).second;
+                }
             }
         }
 
         return owned;
     }
 
+    /* assume lock is held */
     bool Category::ownsAppender(Appender* appender, 
                                 Category::OwnsAppenderMap::iterator& i2) throw() {
         bool owned = false;
@@ -185,12 +218,15 @@ namespace log4cpp {
     }
 
     void Category::callAppenders(const LoggingEvent& event) throw() {
-        if (!_appender.empty()) {
-            for(AppenderSet::const_iterator i = _appender.begin(); i != _appender.end(); i++) {
-                (*i)->doAppend(event);
+        threading::ScopedLock lock(_appenderSetMutex);
+        {
+            if (!_appender.empty()) {
+                for(AppenderSet::const_iterator i = _appender.begin();
+                    i != _appender.end(); i++) {
+                    (*i)->doAppend(event);
+                }
             }
         }
-
         if (getAdditivity() && (getParent() != NULL)) {
             getParent()->callAppenders(event);
         }
@@ -312,7 +348,7 @@ namespace log4cpp {
     }
     
     void Category::error(const char* stringFormat, ...) throw() { 
-               if (isPriorityEnabled(Priority::ERROR)) {
+        if (isPriorityEnabled(Priority::ERROR)) {
             va_list va;
             va_start(va,stringFormat);
                        _logUnconditionally(Priority::ERROR, stringFormat, va);
@@ -321,7 +357,7 @@ namespace log4cpp {
     }
     
     void Category::error(const std::string& message) throw() { 
-               if (isPriorityEnabled(Priority::ERROR))
+        if (isPriorityEnabled(Priority::ERROR))
             _logUnconditionally2(Priority::ERROR, message);
     }
 
