@@ -7,8 +7,8 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/Portability.hh"
-#include "log4cpp/OstringStream.hh"
+#include <log4cpp/Portability.hh>
+#include <log4cpp/OstringStream.hh>
 #ifdef LOG4CPP_HAVE_IO_H
 #    include <io.h>
 #endif
@@ -18,25 +18,30 @@
 
 #include <stdio.h>
 #include <time.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <fcntl.h>
-#include "log4cpp/FileAppender.hh"
-#include "log4cpp/Category.hh"
+#include <log4cpp/FileAppender.hh>
+#include <log4cpp/Category.hh>
 
 namespace log4cpp {
 
     FileAppender::FileAppender(const std::string& name, 
-                               const std::string& fileName) : 
+                               const std::string& fileName,
+                               bool append,
+                               mode_t mode) : 
             LayoutAppender(name),
-            _fileName(fileName) {
-        _fd = ::open(_fileName.c_str(), O_CREAT | O_APPEND | O_WRONLY, 00644);
+            _fileName(fileName),
+            _flags(O_CREAT | O_APPEND | O_WRONLY),
+            _mode(mode) {
+        if (!append)
+            _flags |= O_TRUNC;
+        _fd = ::open(_fileName.c_str(), _flags, _mode);
     }
     
     FileAppender::FileAppender(const std::string& name, int fd) :
         LayoutAppender(name),
         _fileName(""),
-        _fd(fd) {
+        _fd(fd),
+        _flags(O_CREAT | O_APPEND | O_WRONLY),
+        _mode(00644) {
     }
     
     FileAppender::~FileAppender() {
@@ -44,7 +49,30 @@ namespace log4cpp {
     }
 
     void FileAppender::close() {
-        ::close(_fd);
+        if (_fd!=-1) {
+            ::close(_fd);
+            _fd=-1;
+        }
+    }
+
+    void FileAppender::setAppend(bool append) {
+        if (append) {
+            _flags &= ~O_TRUNC;
+        } else {
+            _flags |= O_TRUNC;
+        }
+    }
+
+    bool FileAppender::getAppend() const {
+        return (_flags & O_TRUNC) == 0;
+    }
+
+    void FileAppender::setMode(mode_t mode) {
+        _mode = mode;
+    }
+
+    mode_t FileAppender::getMode() const {
+        return _mode;
     }
 
     void FileAppender::_append(const LoggingEvent& event) {
@@ -56,13 +84,13 @@ namespace log4cpp {
 
     bool FileAppender::reopen() {
         if (_fileName != "") {
-            int fd = ::open(_fileName.c_str(), O_CREAT | O_APPEND | O_WRONLY, 00644);
+            int fd = ::open(_fileName.c_str(), _flags, _mode);
             if (fd < 0)
                 return false;
             else {
-                int oldfd = _fd;
+	        if (_fd != -1)
+                    ::close(_fd);
                 _fd = fd;
-                ::close(oldfd);
                 return true;
             }
         } else {
