@@ -7,8 +7,8 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/Portability.hh"
-#include "log4cpp/FixedContextCategory.hh"
+#include <log4cpp/Portability.hh>
+#include <log4cpp/FixedContextCategory.hh>
 
 namespace log4cpp {
 
@@ -44,7 +44,7 @@ namespace log4cpp {
         return result;
     }
     
-    void FixedContextCategory::addAppender(Appender* appender) {
+    void FixedContextCategory::addAppender(Appender* appender) throw() {
         // XXX do nothing for now
     }
     
@@ -60,7 +60,11 @@ namespace log4cpp {
     const {
         return _delegate.getAppender(name);
     }
-    
+
+    AppenderSet FixedContextCategory::getAllAppenders() const {
+        return _delegate.getAllAppenders();
+    }
+
     void FixedContextCategory::removeAllAppenders() {
         // XXX do nothing for now
     }
