@@ -7,9 +7,9 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/Portability.hh"
-#include "log4cpp/OstringStream.hh"
-#include "log4cpp/LayoutAppender.hh"
+#include <log4cpp/Portability.hh>
+#include <log4cpp/OstringStream.hh>
+#include <log4cpp/LayoutAppender.hh>
 
 namespace log4cpp {
 
