@@ -7,10 +7,10 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/Portability.hh"
-#include "log4cpp/Log4cppCleanup.hh"
-#include "log4cpp/HierarchyMaintainer.hh"
-#include "log4cpp/Appender.hh"
+#include <log4cpp/Portability.hh>
+#include <log4cpp/Log4cppCleanup.hh>
+#include <log4cpp/HierarchyMaintainer.hh>
+#include <log4cpp/Appender.hh>
 #include <iostream>
 
 namespace log4cpp {
@@ -29,11 +29,13 @@ namespace log4cpp {
         std::cerr << "Log4cppCleanup destruct" << std::endl;
 #endif
     
-        if (HierarchyMaintainer::_defaultMaintainer)
-            delete HierarchyMaintainer::_defaultMaintainer;
+        delete HierarchyMaintainer::_defaultMaintainer;
+        HierarchyMaintainer::_defaultMaintainer = NULL;
+
         if (Appender::_allAppenders) {
             Appender::_deleteAllAppenders();
             delete Appender::_allAppenders;
+            Appender::_allAppenders = NULL;
         }            
     }
 }
