@@ -7,8 +7,9 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/Portability.hh"
-#include "log4cpp/LoggingEvent.hh"
+#include <log4cpp/Portability.hh>
+#include <log4cpp/LoggingEvent.hh>
+#include <log4cpp/threading/Threading.hh>
 
 namespace log4cpp {
     
@@ -20,6 +21,6 @@ namespace log4cpp {
         message(message),
         ndc(ndc),
         priority(priority),
-        threadName("thread1") {
+        threadName(threading::getThreadId()) {
     }
 }
