@@ -7,15 +7,18 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/Portability.hh"
-#include "log4cpp/Priority.hh"
+#include <log4cpp/Portability.hh>
+#include <log4cpp/Priority.hh>
+#include <cstdlib>
 
 namespace log4cpp {
 
-    static const std::string names[10] = {
-        "FATAL", "ALERT", "CRIT", "ERROR", "WARN",
-        "NOTICE", "INFO", "DEBUG", "NOTSET", "UNKNOWN" 
-    };
+    namespace {
+        const std::string names[10] = {
+            "FATAL", "ALERT", "CRIT", "ERROR", "WARN",
+            "NOTICE", "INFO", "DEBUG", "NOTSET", "UNKNOWN" 
+        };
+    }
 
     const std::string& Priority::getPriorityName(int priority) throw() {
          
@@ -40,9 +43,9 @@ namespace log4cpp {
 		value = 0;
 	    } else {
 		char* endPointer;
-		value = strtoul(priorityName.c_str(), &endPointer, 10);
+		value = std::strtoul(priorityName.c_str(), &endPointer, 10);
 		if (*endPointer != 0) {
-		    throw std::invalid_argument(std::string("unknown priority name: ") + priorityName);
+		    throw std::invalid_argument(std::string("unknown priority name: '") + priorityName + "'");
 		}
 	    }
 	}
