@@ -7,14 +7,14 @@
  * See the COPYING file for the terms of usage and distribution.
  */
 
-#include "log4cpp/Portability.hh"
+#include <log4cpp/Portability.hh>
 #if LOG4CPP_HAVE_SYSLOG
 
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
-#include "log4cpp/SyslogAppender.hh"
+#include <log4cpp/SyslogAppender.hh>
 
 namespace log4cpp {
 
@@ -64,7 +64,7 @@ namespace log4cpp {
     void SyslogAppender::_append(const LoggingEvent& event) {
 	std::string message(_getLayout().format(event));
         int priority = toSyslogPriority(event.priority);
-	::syslog(priority | _facility, "%s", message.c_str());
+        ::syslog(priority | _facility, "%s", message.c_str());
     }
 
     bool SyslogAppender::reopen() {
